         % FILENAME:     RM2003May07.m
% DESCRIPTION:  Recycling Mirror Triple Pendulum
% RENAME AS HLTS FEB 2010 NAR

%%**********************************************************************
%%COMMENTS%%
%% PARAMETERS FOR THE RM SUSPENSION 
%% VERSION HAS NO LEVER_ARM INPUT
%%**********************************************************************

%****************************************************************************
% FILE LOG:
% Written by CIT 7/98                                               Version 1
% Modified by KAS 6/99 (version 0.5.1)                              Version 2
% Modified by PAW for LIGO recycling mirror triple                  Version 3
% Further modified by NAR April 02                                  Version 4
%   top mass is REPRESENTED by a rectangular BLOCK
%   in reality it will be larger and less dense.
% Modified by CAC on 22nd Jan 2003                                  Version 5
%   Update of NAR's TRIPLEP.M model to incorporate features 
%   of PAW's RMfile.m model.
% Modified by CIT on 29th January 2003                              Version 6
% Cleaned up version with new sub-folders
% Modified by CIT on February 3rd 2003 (02/03/03 CIT)               Version 7
% Changed parameters and tidied up lever arm section
% Modified by CIT on February 10th 2003 (02/10/03 CIT)               Version 8
% Changed radius of lower wire, leverarm and added iy&iz to output
%modified by NAR on 4th March 2003                                  Version 9
%modified by CIT on 7th May 2003
%   includes mass and moments from SWorks                            Version 10
%Updated by NAR as RM design worked on in 2008
% Updated by NAR for HLTS prototype as built parameters Feb 2010
%updated by NAR for HLTS final design review March 2010
%*****************************************************************************

%% coordinates x = longitudinal = u_LIGO roll about this axis
%%             y = transverse   = v_LIGO pitch about this axis
%%             z = vertical     = w_LIGO yaw about this axis

g              = 9.81;

%%%%%%%%%%%%%%%%%%%%%%%%%%% UPPER MASS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%*****1st ATTEMPT*****
%% top mass is REPRESENTED by a rectangular BLOCK
%% in reality it will be larger and less dense.
 %ux	= 0.10;			%dimensions of UPPER MASS (square)
 %uy  =  0.30;
 %uz	= 0.06;
 %den1	= 7000;		%density (steel with holes)
 %m1	= den1* uy* uz* ux;	%mass 
 %I1x	=  m1*( uy^2+ uz^2)/12;	%moment of inertia (transverse roll)
 %I1y	=  m1*( uz^2+ ux^2)/12;	%moment of inertia (longitudinal pitch)
 %I1z	=  m1*( uy^2+ ux^2)/12;	%moment of inertia (yaw)
 %m1_parameters = 'represented by a regtangular block';
 %material1 = 'steel'
%%%%%%%%%%%%%%%%%%%%%%% 
 
%%*****2nd ATTEMPT***** 
%% T-shaped calculated from mofi2.m
% m1             = 12.65;
% I1x            = 8.96e-2;
% I1y            = 2.76e-2;
% I1z            = 8.30e-2;

% m1             = 12.168; %top piece 0.1x0.44x0.017m, bottom piece 0.1x0.116x0.07m NAR 4 Mar 2003
% I1x            = 10.97e-2;  
% I1y            = 1.8613e-2;
% I1z            = 11.137e-2;

% m1_parameters = 'T-shaped calculated from mofi2.m';
% material1 = 'steel';
%%%%%%%%%%%%%%%%%%%%%%% 
 
%%*****3rd ATTEMPT***** 
%% FROM SOLIDWORKS ASSEMBLY OR ACTUAL MASS
 %m1 =     12.07;      %Actual shape calculated from SWorks 01/09/02
 %I1x =    1.263e-1;   %top plate 100X440X20mm / T-section 96X116X64mm
 %I1y =    1.857e-2;
 %I1z =    1.274e-1;
 %m1_parameters = 'Calculated from SWorks Assem 2003Mar26';
 %material1 = 'combination steel+alum';
%%%%%%%%%%%%%%%%%%%%%%%

 m1 =     12.07;      %From Solidworks B Kirsner e-mail 13 May 2008
 
 m1 = 11.91; %As-built, info posted on wiki Feb 2010 (Derek Bridges)
 
 I1x =    1.225e-1;   %From Solidworks B Kirsner e-mail 13 May 2008
 I1y =    1.813e-2;     %From Solidworks B Kirsner e-mail 13 May 2008
 I1z =    1.237e-1;     %From Solidworks B Kirsner e-mail 13 May 2008
%m1_parameters = 'Calculated from SWorks Assem 2008';


 %pend.m1_parameters = m1_parameters;
 %pend.material1 = material1;
 pend.m1 = m1;
 pend.I1x = I1x;
 pend.I1y = I1y;
 pend.I1z = I1z;

%*********************************************************************************
%%%%%%%%%%%%%%%%%%%%INTERMEDIATE MASS%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1st Attempt - NOISE PROTOTYPE
% Silica cylindrical mass
 %ix	    = 0.10;			%dimension of INTERMEDIATE MASS (cylinder)
 %ir	    = 0.1325;

%den2	= 2202;			%density (fused silica)
%m2	    = den2*pi* ir^2* ix	;%intermediate mass
%I2x	= m2*(ir^2/2);		%moment of inertia (transverse roll)
%I2y	= m2*(ir^2/4+ix^2/12);	%moment of inertia (longitudinal pitch)
%I2z	= m2*(ir^2/4+ix^2/12);	%moment of inertia (yaw)
%m2_parameters = 'Noise P-type: Silica Mass';
%material2 = 'silica';

% 2nd Attempt  - CONTROLS PROTOTYPE
% Aluminium "dummy" intermediate mass
% ix             = 0.10;                 %dimensions of INTERMEDIATE MASS (square)
% iy             = 0.265;                %incorporated by CAC 01/2003
% iz             = 0.10;                 %incorporated by CAC 01/2003
% den2           = 4600;                 %combined aluminium and steel to give same mass as m3
% m2             = den2* iy* iz* ix;     %mass     %changed by CIT 01/29/2003
% I2x            =  m2*( iy^2+ iz^2)/12; %moment of inertia (transverse roll)
% I2y            =  m2*( iz^2+ ix^2)/12; %moment of inertia (longitudinal pitch)
% I2z            =  m2*( iy^2+ ix^2)/12; %moment of inertia (yaw)
%m2_parameters = 'Controls P-type: Rectangular block';
%material2 = 'alum with holes + s/steel clamps'; 

% 3rd Attempt  - CONTROLS PROTOTYPE
% Aluminium "dummy" intermediate mass

%ix	    = 0.1;			%dimension of INTERMEDIATE MASS (RECTANGLE)
%iy	    = 0.255; 
%iz      = 0.092;
%m2 =    12.214;     %Actual shape calculated from SWorks
%I2x =   8.162e-2;   %Dimensions 100X255X92mm   
%I2y =   2.035e-2;
%I2z =   8.143e-2;
%m2_parameters = 'Controls P-type: Calculated from SWorks Assembly';
%material2 = 'alum + s/stl inserts + s/stl clamps'; 

m2 =    12.10;     %From Solidworks B Kirsner e-mail 13 May 2008

m2 =  12.15; %As-built, info posted on wiki Feb 2010 (Derek Bridges)

I2x =   8.207e-2;   %From Solidworks B Kirsner e-mail 13 May 2008  
I2y =   1.996e-2;   %From Solidworks B Kirsner e-mail 13 May 2008
I2z =   8.190e-2;   %From Solidworks B Kirsner e-mail 13 May 2008




%pend.m2_parameters = m2_parameters;
 %pend.material2 = material2;
 %pend.ix = ix;
 %pend.iy = iy;
 %pend.iz = iz;
 pend.m2 = m2;
 pend.I2x = I2x;
 pend.I2y = I2y;
 pend.I2z = I2z;
 
%*******************************************************************************
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% TEST MASS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1st Attempt - NOISE PROTOTYPE
% Silica cylindrical test mass
 tx             = 0.10;                 %dimensions of TEST MASS (cylinder)
 tr             = 0.1325;
 
  %tx             = 0.10;                 %dimensions of TEST MASS (cylinder)
 %tr             = 0.1425;  %revised size Feb 2007 return to original size
 %April 2007
 
 
 
 
 
 %den3	= 2202;			%density (fused silica)
 
 % Noted added Feb 2008 - Garilynn has density of 2201 kg/m3 for the type
 % we will use
 den3	= 2201;
 
 m3	    = den3*pi*tr^2*tx;	%test mass 
 I3x	= m3*(tr^2/2);		%moment of inertia (transverse roll)
 I3y	= m3*(tr^2/4+tx^2/12);	%moment of inertia (longitudinal pitch)
 I3z	= m3*(tr^2/4+tx^2/12);	%moment of inertia (yaw)
%m3_parameters = 'Noise P-type: Silica Mass without flats and ears';
 %material3 = 'silica';
 % note added Oct 2008. Actual optics will be 101.4 mm thick at thick end, with
 % wedge 0.6 degrees, symmetric and vertical. Mass stays same as with 100mm thick and no wedge
 % see RODA M080041
 
 %further update March 2010 the wedge is now asymmetric. See drawings PR3 - D080662,
 %F-PR3 - D080663 and SR3 - D080664, and heavy side down as per T080078
 %table 1 RODA M080041 has been updated.
 
 % BK7 test mass (as proposed in COC PDR Feb 2008)has density 2510 kg/m^3
 %keep mass the same by reducing thickness - 
 %it becomes 0.1 m x 2.201/2.51 = 0.0877 m
 
  %tx             = 0.0877;                 %dimensions of TEST MASS (cylinder)
 %tr             = 0.1325;
 
 
 %den3	= 2510;			%density (BK7)
 %m3	    = den3*pi*tr^2*tx;	%test mass 
 %I3x	= m3*(tr^2/2);		%moment of inertia (transverse roll)
 %I3y	= m3*(tr^2/4+tx^2/12);	%moment of inertia (longitudinal pitch)
 %I3z	= m3*(tr^2/4+tx^2/12);	%moment of inertia (yaw)
%m3_parameters = 'Noise P-type: BK7 Mass without flats and ears';
 %material3 = 'BK7';
 
 
 
% 2nd Attempt - CONTROLS PROTOTYPE
% Aluminium "dummy" test mass
%tx             = 0.10;                 
%tr             = 0.265/2;
%m3 =    12.181;     %Actual shape calculated from SWorks 01/09/02
%I3x =   1.051e-1;   % dimensions 100mm thick x 265mm diam
%I3y =   6.277e-2;
%I3z =   6.259e-2;
%m3_parameters = 'Controls P-tpye: Calculated from SWorks Assembly';
%material3 = 'alum with holes, flats + s/stl clamps';

% dummy bottom mass, email from Derek 10 Feb 2010

 %m3	    = 12.09;	%test mass 
 %I3x	= 1.20e-1;		%moment of inertia (transverse roll)
 %I3y	= 6.99e-2;	%moment of inertia (longitudinal pitch)
 %I3z	= 7.07e-2;	%moment of inertia (yaw)


 %pend.m3_parameters = m3_parameters;
 %pend.material3 = material3;
 pend.tx = tx;
 pend.tr = tr;
 pend.m3 = m3;
 pend.I3x = I3x;
 pend.I3y = I3y;
 pend.I3z = I3z;
 
%***********************************************************************************************


 l1             = 0.20;                 %upper wire length, changed from .25 by PAW 12/2001
 %l2            = 0.234;                %intermediate wire length
 %l2            = 0.25;                 %increased to give good clearance between masses w/ T top mass NAR Apr02

 
 l2             = 0.201;                %intermediate wire length changed from 0.234 by PAW 7/2002
                                        %incorporated by CAC 01/2003
 %l3            = 0.30;                 %lower wire length, changed from .20 by PAW 12/2001
 
 l3             = 0.253;                %lower wire length, changed from 0.30 by PAW 7/2002
                                        %incorporated by CAC 01/2003
                                        
  % change lengths to get agreement with  model in which flexure lengths had been added  
  %into calculation of length, 28th Jan 2008 (see my notebook 4 page 118)      
  %l1 = 0.2025;
  %l2 = 0.2035;
  %l3 = 0.2555;
  %numbers as per e-mail from Bob Kirsner 26 Feb 2008 with correction of 
  % 1mm to bottom length - confirmed 7th April 2008
   l1 = 0.2025;
  l2 = 0.2036;
 l3 = 0.2552;
 
 %try ls all same 2nd dec 2008
   %l1 = 0.222;
  %l2 = 0.224;
 %l3 = 0.214;
  
pend.l1         = l1;
pend.l2         = l2;
pend.l3         = l3;
%******************************************************************************************


 nw1            =2;                     %number of wires (= number of cantilevers if fitted) per stage (2 or 4)
 nw2            =4;
 nw3            =4;
pend.nw1        = nw1;
pend.nw2        = nw2;
pend.nw3        = nw3;
%***********************************************************************************


 r1             = 300e-6;               %radius of upper wire gives stress 6.3e8 Pa for mass 36.43kg,2 wires
 %r2             = 200e-6;               %radius of intermediate wire 
 
%%CONTROLS PROTOTYPE
 %r3_parameters = 'Spring Steel Wires';
 %r3	    = 140e-6;	% radius of lower wire UPDATED 10th FEB CIT, previously 200e-6
 
 r2 = 170e-6; % stress 6.6e8 Pa for mass 24.36 kg, 4 wires May 2007
 r3=120e-6;% stress 6.6e8 Pa for mass 12.15 kg on 4 wires May 2007

r3 = 135e-6; % push up vertical frequency to make close to the same as small triple at 28.25 Hz
%Oct2008 
%Note small triple now 27.8 Hz due to revised Young's mod value Dec 5th 2008
%but wont change r again at present - need to check on commerical availability
r3 = 133e-6;

%5th/ 6th Aug 2009. Try changing r to get f = 23.1 Hz, same as HSTS ( see notes in lab book
%NAR) Assumes we can go to higher stress as per ASTM document
%r3 = 110e-6; %gives f = 23.1 Hz
%r3 = 88e-6; % gives f = 18.5 Hz

% As-built wires Feb 2010 from wiki (Derek Bridges)
r1= (610e-6)/2;
r2 = (340e-6)/2;
r3 = (269e-6)/2;

 pend.r1 = r1;
 pend.r2 = r2;
 %pend.r3_parameters = r3_parameters;
 pend.r3 = r3;



%************************************************************************************

 Y1	= 2.2e11;			%Youngs Modulus of upper wire  (s/steel 302)
                        % Changed to YM for California Steel Wire by CIT 01/09/02, previously 1.65e11
 Y2	= 2.2e11;			%Youngs Modulus of intermediate wire (s/steel 302)
                        % Changed to YM for California Steel Wire  by CIT 01/09/02

%%CONTROLS PROTOTYPE
 %Y3_parameters = 'Spring Steel Wires';
 Y3	= 2.2e11;			%Youngs Modulus of lower wire (s/steel 302)
                        % Changed to YM for California Steel Wire  by CIT 01/09/02 
                        
  Y1 = 2.12e11; % number as measured by MB, 11/18/05
  Y2 = 2.12e11; % number as measured by MB, 11/18/05
  Y3 = 2.12e11; % number as measured by MB, 11/18/05
                                        
%%NOISE PROTOTYPE
 %Y3_parameters = 'Fused-Silica Fibres';
 %Y3	    = 7e10;			% Youngs Modulus of lower wire	(fused silica)
                                        
pend.Y1             = Y1;
pend.Y2             = Y2;
%pend.Y3_parameters  = Y3_parameters;
pend.Y3             = Y3;

%************************************************************************************************************

% THE opt.m function is used to estimate a cantilever blade in order to get started.
% In order to take the design of a Cantilever blade forward it is necessary to used the EXCEL and ANSYS model.
% It is then necessary to override opt.m with the calculated numbers (an example is shown below on line 196


%blade design - upper blades
 mntb           = (m1 +m2 +m3)/2;         %total per blade
 mnb            = m1/2;                   %uncoupled mass
 
 %[uf,lnb,anb,hnb,stn] = opt(mnb,mntb,8e8,0.28,0.07);
  [uf,lnb,anb,hnb,stn] = opt(mnb,mntb,8e8,0.25,0.065);      %changed by NAR, same length as MC
 
 %ufc1           = uf;
 %pend.l1b       = lnb;
 %pend.a1b       = anb;
 %pend.h1b       = hnb;
 %pend.ufc1      = uf;
%pend.st1       = stn;
 %pend.intmode_1 = 55*hnb*0.37^2/(0.002*lnb^2); %scaled from GEO blade

 
 %*****************************
 %NAR override 
 %Upper blades:length: 25 cm, width: 6.5 cm, thickness: 2.3 mm, max. defl.: 104.8 mm, ufc1: 2.6 Hz (shape factor of 1.36).
 %masses from top to bottom of 12.6, 12.2, and 12.15 kg.
 %ufc1=2.6;          % MIKE PLISSI JAN/29/2003
 %pend.ufc1 = ufc1;
 
  %Note added 17th july 2007 Top mass is now 12.07 kg.
 % blades 25cm x 6.5 cm x 2.3 mm, alpha 1.36 gives freq 2.7 Hz, 
 %alpha 1.55 gives freq 2.52 Hz
 
 % these are values being used in prototype ref BLADE_RMv2_March30_2009
   pend.l1b       = 0.25;
 pend.a1b       = 0.065;
 pend.h1b       = 2.3e-3;
  ufc1=2.7;
 pend.ufc1 = ufc1;
 
 % Note added Oct 10th 2008. Higher stress (978 Mpa vs 777 MPa) 
 %with blade thickness 2.05 mm
 % other parameters same. Gives following ufc1, see BLADE_RMv2_higher_stress.xls
  pend.l1b       = 0.25;
 pend.a1b       = 0.065;
 pend.h1b       = 2.05e-3;
   ufc1=2.27;        
 pend.ufc1 = ufc1;
 
% pend.kx1	=  20 * 1/2 * (2*pi*pend.ufc1)^2*pend.m1 % guesstimate of blade lateral compliance - uncomment this and pend.kx2 below to test symbexport3lat.m and symbexport3latfull.m

 %*******************************************
 
%blade design - lower blades
 mntb           = (m2 +m3)/4;             %total per blade
 mnb            = m2/4;                   %uncoupled mass

 %[uf,lnb,anb,hnb,stn] = opt(mnb,mntb,8e8,0.20,0.05);
 [uf,lnb,anb,hnb,stn] = opt(mnb,mntb,8e8,0.12,0.04);        %changed by NAR, same length as MC
 
 %ufc2           = uf;
 %pend.l2b       = lnb;
 %pend.a2b       = anb;
 %pend.h2b       = hnb;
 %pend.ufc2      = uf;
 %pend.st2       = stn;
 %pend.intmode_2 = 55*hnb*0.37^2/(0.002*lnb^2); %scaled from GEO blade

%********************* 
%NAR override
%Lower blades:length: 12 cm, width: 4.0 cm, thickness: 1.2 mm, max. defl.: 49.9 mm, ufc2: 3.2 Hz (shape factor of 1.55).
%masses from top to bottom of 12.6, 12.2, and 12.15 kg. 
 %ufc2=3.2;              % MIKE PLISSI JAN/29/2003
 %pend.ufc2 = ufc2;
 %Note added 17th July - top mass is now 12.07 kg but makes no difference
 %to these blades
 
 %Note added 31 Aug 2007. In fact we had changed in 2003 to
 %different size of blades - 32 mm wide, 120 mm long and 1.3 mm thick. This
 %gives essentially same frequency. alpha 1.55 for these smaller blades
 %See file BLADE_RMv2.xls
 
 pend.l2b       = 0.12;
 pend.a2b       = 0.032;
 pend.h2b       = 1.3e-3;
ufc2 = 3.18;
pend.ufc2 = ufc2;
%The above from refBLADE_RMv2_March30_2009 

% note added Oct 10th 2008. Higher stress ( 977 vs 791 Mpa)with thickness 1.17 mm 
%other parameters unchanged 
%Gives following uf21, see BLADE_RMv2_higher_stress.xls

 pend.l2b       = 0.12;
 pend.a2b       = 0.032;
 pend.h2b       = 1.17e-3;
ufc2 = 2.73;
pend.ufc2 = ufc2;

% pend.kx2	=  20 * 1/2 * (2*pi*pend.ufc2)^2*pend.m2 % guesstimate of blade lateral compliance - uncomment this and pend.kx1 above to test symbexport3lat.m and symbexport3latfull.m

%**********************************************
%new d code is given further on 27th Jan 2008
 
 %d0             = 0.001;                %height of upper wire break-off (above c.of m. upper mass)
 %d1             = 0.001;                %height of intermediate wire break-off (below c.of m. upper mass)
 %d2             = 0.001;                %height of intermediate wire break-off (above c.of m. of int. mass)
 %d3             = 0.001;                %height of lower wire break-off (below c.of m. intermediate mass)
 %d4             = 0.001;                %height of lower wire break-off (above c.of m.test mass)
 
 
 
%d0             = 0.0036;                %with flexure lengths May 07 
%d1             = 0.0024;                %lengths as calc. by MB code
 %d2             = 0.0024;                %which allows for angling of wires
 %d3             = 0.0021;                
 %d4             = 0.0021; 
 
 
 
 
 
 %pend.d0        = d0;                   %added CIT PAW 12/2001
 %pend.d1        = d1;
 %pend.d2        = d2;
 %pend.d3        = d3;
 %pend.d4        = d4;
 %pend.di = 'all 0.001'; %commented out NAR April02
%******************************************************************************************


% X direction separation


 su             = 0.00;                 % 1/2 separation of upper wires  
 %si             = 0.028;                % 1/2 separation of intermediate wires 
 si             = 0.03;                 %optimise damping of pitch highest mode NAR 4 Mar03
 sl             = 0.005;                % 1/2 separation of lower wires 

 pend.su        = su;
 pend.si        = si;
 pend.sl        = sl;
 %******************************************************************************************
 
%!!!!!!!!!!!!????!! NEED TO LOOK AT THE N's WRT MPL's LAYOUT!!!!!!!!??? 
 
% Y direction separation


%n0            = 0.06;                 % 1/2 separation of upper wires at suspension point
 n0             = 0.077;                % changed by NAR for similar footprint to MC
 n1             = 0.13;                 % 1/2 separation of upper wires at upper mass

                                        % incorporated by CAC 01/2003
%n2             = 0.03;                 % 1/2 separation of intermediate wires at upper mass - TO BE CONFIRMED
                                        % incorporated by CAC 01/2003
 n2             = 0.06;                 % CIT 02/04/03 CIT IN ORDER TO FIT WITH CLEARANCE OF THE 'T'-PIECE
 n2             = 0.07;                  %increased to accommodate wider T piece NAR 4MAr03

 %n3            = ir+0.0065;            % 1/2 separation of intermediate wires at intermediate mass
 %n3            = ir+0.0095;            % increased to give clearance of wire from edge of penultimate mass
 
 %n3             = iy/2+0.0139;          % 1/2 separation of intermediate wires at intermediate mass
                                        % incorporated by CAC 01/2003  
 n3 = 0.1275+0.01;                            % new number from CIT         
 
 n4             = tr+0.0015;            % 1/2 separation of lower wires at intermediate mass
 n4             = tr+0.005;            % allow for breakoff on side of curved mass NAR Feb2007
 %n4 = 0.1275+0.01;                           % new number from CIT
 
 n4 = 0.1455;   %revised number from B Kirsner June 2007, flats removed from mass
 
 n5             = tr+0.0015;            % 1/2 separation of lower wires at test mass
  n5             = tr+0.005;           % allow for breakoff on side of curved mass NAR Feb2007
 %n5 = tr-0.0024+0.0074;                 % new number from CIT
 
 n5 = 0.1455;   %revised number from B Kirsner June 2007, flats removed from mass
 
 n4 = 0.1325+0.008; %updated to reflect sapphire rposim break-off design, 8 mm, 3rd April 2009
 n5 = 0.1325+0.008; %updated to reflect sapphire rposim break-off design, 8 mm, 3rd April 2009
 
 pend.n0        = n0;
 pend.n1        = n1;
 pend.n2        = n2;
 pend.n3        = n3;
 pend.n4        = n4;
 pend.n5        = n5;
 
 
 %--------------
 c1=sqrt(l1^2-(n1-n0)^2)/l1;
 c2=sqrt(l2^2-(n3-n2)^2)/l2;
 c3=sqrt(l3^2-(n5-n4)^2)/l3;

 M11 = (1/4)*pi*r1^4;
 M21 = (1/4)*pi*r2^4;
 M31 = (1/4)*pi*r3^4;
 flex1 = sqrt(nw1*M11*Y1/(m1+m2+m3)/g)*c1^(3/2);
 flex2 = sqrt(nw2*M21*Y2/(m2+m3)/g)*c2^(3/2); 
 flex3 = sqrt(nw3*M31*Y3/m3/g)*c3^(3/2); 
 
 pend.stage2 = 1;
 
 d0     = 0.001-flex1;        %height of upper wire break-off (above c.of m. upper mass)
 d1     = 0.001-flex2;        %height of intermediate wire break-off (below c.of m. upper mass)


 d2     = 0.001-flex2;        %height of intermediate wire break-off (above c.of m. of int. mass)
 d3     = 0.001-flex3;        %height of lower wire break-off (below c.of m. intermediate mass)
 d4     = 0.001-flex3;        %height of lower wire break-off (above c.of m.test mass)
 
 %Set physical values at 0.001m, and overall ds as 0.001 mm plus the flex
 %lengths 27 Jan 2008
  d0     = 0.001;        %height of upper wire break-off (above c.of m. upper mass)
 d1     = 0.001;        %height of intermediate wire break-off (below c.of m. upper mass)
  % trying changing this by +/- 2 mm (corresponding to adding or subtracting mass at
 % intermediate mass) 9th May 2008
 %d1 = 0.003;
 d2     = 0.001;        %height of intermediate wire break-off (above c.of m. of int. mass)
 d3     = 0.001;        %height of lower wire break-off (below c.of m. intermediate mass)
 d4     = 0.001;        %height of lower wire break-off (above c.of m.test mass)
 
  
 pend.d0        = d0;                   %added CIT PAW 12/2001
 pend.d1        = d1;
 pend.d2        = d2;
 pend.d3        = d3;
 pend.d4        = d4;
 %-------------------------
% overall length calculation added by CIT and PAW 12/2001 

% note added 26th Jan 2008. These lengths are recalculated in ssmake3MB
% where tl1 etc are centre to centre of masses and not as below (which
% doesnt include the ds)
% When listing parameters using pend.ref it calls ssmake3MB

%pend.tl1        = sqrt(pend.l1^2 - (pend.n0-pend.n1)^2);
%pend.tl2        = sqrt(pend.l2^2 - (pend.n2-pend.n3)^2);
%pend.tl3        = sqrt(pend.l3^2 - (pend.n4-pend.n5)^2);
%overall length to the centre of mass of the test mass
%pend.l_cofm     = pend.tl1+pend.tl2+pend.tl3+pend.d0+pend.d1+pend.d2+pend.d3+pend.d4;   
%overall length including the radius of the test mass
%pend.l_total    = pend.tl1+pend.tl2+pend.tl3+pend.d0+pend.d1+pend.d2+pend.d3+pend.d4+pend.tr;




%***********************************************************************************


% represents small loss


 bd             = 0.01;                 % makes phases of open loop plots look nicer

bd=0.0;
 
 
%****************************************************************************************************** 
%IMPORTANT FOR REFERENCE ONLY!!! 
% THE FOLLOWING IS USED TO EXPLAIN THE CALCULATION OF THE NUMBER USED IN THE GAIN TRIANGLE
%Gain triangles in pendn.m

% lever_pitch   = 0.04;                 %PW DEC 02
% lever_yaw     = 0.1;                  %PW DEC 02
% lever_roll    = 0.1;                  %PW DEC 02    %UPDATED 10th FEB 2003 CIT

%% lever_pitch   = 0.03;                %changed by NAR to be same as MC
%% lever_yaw     = 0.08;                %changed by NAR to be same as MC
%% lever_roll    = 0.06;                %changed by NAR to be same as MC              

% pend.lever_pitch = lever_pitch; 
% pend.lever_yaw = lever_yaw; 
% pend.lever_roll = lever_roll;

%gain   = -0.2;                          %PW DEC 02

%% gain = -0.4;                          %changed by NAR to be same as MC  

%Gain triangle = (leverarm)^2 * (no. of coils) * gain


%***Note that gains are linked in different directions due to common coils as below*****
%***If gains in one channel only need to be changed then leverarm can be used***********


%gainzrtrl =gain;       % vertical, z, pitch, rt, roll rl (coils on top of upper mass)
%gaint   = gain.*2;     % transverse, t (coil on one end of upper mass)
%gainlrz = gain;        % longitudinal, l, yaw, rz (coils on long rear side of upper mass) 

%EQUATIONS

%long   = (1)^2             *  2 * gainlrz      = -0.4       incorporated by CAC 01/2003 TO BE CONFIRMED
%pitch  = (lever_pitch)^2   *  2 * gainzrtrl    = -0.00064   incorporated by CAC 01/2003 TO BE CONFIRMED
%vert   = (1)^2             *  3 * gainzrtrl    = -0.6       incorporated by CAC 01/2003 TO BE CONFIRMED
%yaw    = (lever_yaw)^2     *  2 * gainlrz      = -0.004     incorporated by CAC 01/2003 TO BE CONFIRMED
%trans  = (1)^2              *  1 * gaint       = -0.4       incorporated by CAC 01/2003 TO BE CONFIRMED
%roll   = (lever_roll)^2 *  3 * gainzrtrl       = -0.006     incorporated by CAC 01/2003 TO BE CONFIRMED

% NOTE: - NUMBERS ON RHS OF ABOVE EQUATIONS ARE CONSISTENT WITH GAIN AND LEVER ARMS SUPPLIED   %
%  BY PW in Dec 02, AS SHOWN ABOVE                                                              %

%long   = (1)^2             *  2 * gainlrz      = -0.4       
%pitch  = (lever_pitch)^2   *  2 * gainzrtrl    = -0.00081        lever arm 0.045
%vert   = (1)^2             *  3 * gainzrtrl    = -0.6       
%yaw    = (lever_yaw)^2     *  2 * gainlrz      = -0.00256     lever arm 0.08
%trans  = (1)^2              *  1 * gaint       = -0.4       
%roll   = (lever_roll)^2 *  3 * gainzrtrl       = -0.00384     lever arm 0.08

% the above set of numbers with alternative lever arms as shown, gain still -0.2 NAR 4Mar 03

% numbers below correspond to gain = -0.4 and lever arms as shown NAR FEB
% 2007

%long   = (1)^2             *  2 * gainlrz      = -0.8       
%pitch  = (lever_pitch)^2   *  2 * gainzrtrl    = -0.00162        lever arm 0.045
%vert   = (1)^2             *  3 * gainzrtrl    = -1.2       
%yaw    = (lever_yaw)^2     *  2 * gainlrz      = -0.00512     lever arm 0.08
%trans  = (1)^2              *  1 * gaint       = -0.8       
%roll   = (lever_roll)^2 *  3 * gainzrtrl       = -0.00432     lever arm 0.06

% design in solidworks at March 2008 has roll leverarm 0.08, others as
% shown above
%This gives revised entry as
%roll   = (lever_roll)^2 *  3 * gainzrtrl       = -0.00768    lever arm 0.08
% Note - the pendn is still carrying 0.06 for roll. Need to check why

%Bob Kirsner has asked to change the roll lever-arm to 0.07 m to reduce an
%interference on top mass. pendn updated Mar 31 2008
%long   = (1)^2             *  2 * gainlrz      = -0.8       
%pitch  = (lever_pitch)^2   *  2 * gainzrtrl    = -0.00162        lever arm 0.045
%vert   = (1)^2             *  3 * gainzrtrl    = -1.2       
%yaw    = (lever_yaw)^2     *  2 * gainlrz      = -0.00512     lever arm 0.08
%trans  = (1)^2              *  1 * gaint       = -0.8       
%roll   = (lever_roll)^2 *  3 * gainzrtrl       = -0.00588    lever arm 0.07








%*******************************************************************************************************
%****************************************************************************************************** 

%VIEWER PREFERENCES (under edit on LTI viewer)

%UNITS
%Frequency in Hz using Log scale
%Magnitude in absolute using log scale
%Phase in degrees


%TIME VECTOR
%[0:0.01:50]

%FREQUENCY VECTOR
%logspace(-0.5,1.5,500)
